@@ -6,14 +6,15 @@ OC.L10N.register(
     "Contacts" : "Kontakte",
     "A contacts app for Nextcloud" : "’n Kontakte-toep vir Nextcloud",
     "Loading …" : "Laai …",
-    "Download" : "Laai Af",
     "Rename" : "Hernoem",
     "Delete" : "Skrap",
+    "Download" : "Laai Af",
     "Copied" : "Gekopieer",
     "Copy link" : "Kopieer skakel",
     "Share with users or groups" : "Deel met gebruikers of groepe",
     "No users or groups" : "Geen gebruikers of groepe",
     "can edit" : "kan wysig",
+    "Add" : "Voeg by",
     "First name" : "Naam",
     "Last name" : "Van",
     "Display name" : "Vertoonnaam",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "Contact" : "Kontak",
     "Admin" : "Admin",
     "Owner" : "Eienaar",
-    "Users" : "Gebruikers",
     "Detailed name" : "Gedetailleerde naam",
     "Additional names" : "Addisionele name",
     "Prefix" : "Voorvoegsel",
