@@ -9,6 +9,9 @@ OC.L10N.register(
     "Copy to full name" : "フルネームをコピー",
     "Omit year" : "年を省略する",
     "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
+    "Please select a team" : "チームを選択してください",
+    "Loading team…" : "チームを読み込み中...",
+    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
     "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
     "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Loading contacts …" : "連絡先を読み込み中...",
@@ -18,32 +21,44 @@ OC.L10N.register(
     "Create contacts" : "連絡先を作成",
     "Add contacts" : "連絡先を追加",
     "Loading …" : "読み込み中…",
-    "Add member" : "メンバーの追加",
+    "Manage team" : "チームを管理",
+    "Leave team" : "チームを離脱",
+    "Delete team" : "チームを削除",
     "Contacts settings" : "連絡先の設定",
     "General settings" : "一般設定",
     "Update avatars from social media" : "SNSでアバターをアップデート",
     "(refreshed once per week)" : "(週に1回更新)",
     "Address books" : "アドレス帳",
+    "Rename" : "名前を変更",
     "Export" : "エクスポート",
     "Send email" : "メールを送信",
     "Send email as BCC" : "BCCでメール送信",
+    "Delete" : "削除",
     "Contact groups" : "連絡先グループ",
     "Create a new contact group" : "新規連絡先グループを作成",
     "Contact group name" : "連絡先グループ名",
+    "Teams" : "チーム",
+    "Create a new team" : "新しいチームを作成する",
+    "Open the contacts app settings" : "連絡先アプリの設定を開く",
     "Show all groups" : "すべてのグループを表示",
     "Collapse groups" : "グループを折りたたむ",
+    "Show all teams" : "すべてのチームを表示",
+    "Collapse teams" : "チームを折りたたむ",
     "This group already exists" : "このグループはすでに存在しています",
+    "This team already exists" : "このチームはすでに存在しています",
+    "An error happened during the creation of the team" : "チームの作成中にエラーが発生しました",
     "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
     "Download" : "ダウンロード",
     "Show" : "表示",
-    "Rename" : "名前を変更",
-    "Delete" : "削除",
+    "Unshare from me" : "共有を自分から解除",
     "Copied" : "コピーしました",
     "Cannot copy" : "コピーできません",
     "Copy link" : "リンクをコピー",
     "Toggling of address book was not successful" : "アドレス帳の切り替えに失敗",
     "This will delete the address book and every contacts within it" : "これはアドレス帳とその中のすべての連絡先を削除します",
     "Delete {addressbook}?" : "{addressbook} を削除しますか？",
+    "This will unshare the address book and every contacts within it" : "これにより、アドレス帳とその中のすべての連絡先の共有が解除されます",
+    "Unshare {addressbook}?" : "{addressbook}の共有を解除しますか?",
     "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
     "_%n contact_::_%n contacts_" : ["%n 連絡先"],
@@ -62,6 +77,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
     "Choose a vCard file to import" : "インポートするvCardファイルを選択",
     "Add new address book" : "新しいアドレス帳を追加する",
+    "Add" : "Add",
     "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
     "First name" : "名",
     "Last name" : "姓",
@@ -74,17 +90,30 @@ OC.L10N.register(
     "Oversees" : "統括",
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "Password protection" : "パスワード保護",
+    "Enforce password protection on files shared to this team" : "このチームと共有するファイルにパスワード保護を強制します",
+    "Use a unique password for all shares to this team" : "このチームのすべての共有に一意のパスワードを使用します",
     "Unique password …" : "固有パスワード...",
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
+    "Team owned by {owner}" : "{owner}が所有するチーム",
+    "Team settings" : "チーム設定",
     "Request to join" : "参加リクエスト",
     "Description" : "詳細",
-    "Add members" : "メンバーの追加",
+    "Members" : "メンバー",
+    "Manage members" : "メンバーの管理",
+    "Team members" : "チームのメンバー",
+    "Team resources" : "チームのリソース",
+    "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
+    "Team name" : "チーム名",
     "Settings" : "Settings",
+    "Actions" : "アクション",
+    "There is no description for this team" : "このチームの説明はありません",
+    "Enter a description for the team" : "チームの説明を入力します",
     "An error happened during description sync" : "説明の同期中にエラーが発生しました",
     "An error happened during name sync" : "名前の同期中にエラーが発生しました",
     "Cancel" : "キャンセル",
+    "Confirm" : "承認",
     "Add more info" : "さらに情報を追加",
     "More fields" : "その他のフィールド",
     "Crop contact photo" : "写真を切り抜き",
@@ -106,6 +135,8 @@ OC.L10N.register(
     "Name" : "名前",
     "Title" : "タイトル",
     "Company" : "会社",
+    "Go to talk conversation" : "Talkのチャットへ移動",
+    "View profile" : "プロフィールを表示",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
     "Edit" : "編集",
     "Clone contact" : "連絡先の複製",
@@ -113,8 +144,11 @@ OC.L10N.register(
     "Contact vCard as QR code" : "QRコードでの連絡先vCard",
     "Pick an address book" : "アドレス帳を選ぶ",
     "Select address book" : "アドレス帳を選ぶ",
-    "Go to talk conversation" : "Talkのチャットへ移動",
-    "View profile" : "プロフィールを表示",
+    "Media shares with you" : "メディアはあなたと共有済み",
+    "Talk conversations with you" : "あなたと会話",
+    "Calendar events with you" : "カレンダーイベント",
+    "Deck cards with you" : "デッキカード",
+    "No shared items with this contact" : "この連絡先との共有アイテムはありません",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
     "Address book" : "アドレス帳",
@@ -135,12 +169,22 @@ OC.L10N.register(
     "No results" : "該当なし",
     "Add to group" : "グループに追加",
     "Add {type}" : "{type}を追加",
+    "New team name" : "新しいチーム名",
+    "Personal team" : "パーソナルチーム",
+    "This team will only be visible to you. Other members will not be able to see or use it." : "このチームはあなたにしか見えません。他のメンバーは表示または使用できません。",
+    "Local team" : "ローカルチーム",
+    "This team will not be shared with the other instances of the global scale" : "このチームはグローバルスケールの他のインスタンスと共有されません",
+    "Create team" : "チームを作成する",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
+    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
     "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
+    "Add members" : "メンバーの追加",
+    "Show team details" : "チームの詳細を表示",
     "Add to {circle}" : "{circle} に追加",
     "Unable to get the recommendations list" : "おすすめリストを取得できません",
     "Unable to get the results" : "結果を取得できません",
     "Some members could not be added" : "一部のメンバーを追加できませんでした",
+    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
     "Accept membership request" : "メンバーシップリクエストを受け入れる",
     "Reject membership request" : "メンバーシップリクエストを拒否",
     "Manage level" : "レベルを管理",
@@ -171,14 +215,23 @@ OC.L10N.register(
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "Import" : "インポート",
+    "Are you sure you want to import this contact file?" : "この連絡先ファイルをインポートしますか?",
     "Could not copy" : "コピーできませんでした",
+    "Join team" : "チームに参加する",
     "You are about to leave {circle}.\nAre you sure?" : "{circle}を離れようとしています。\nよろしいですか？",
+    "Please confirm team leave" : "チームの離脱を確認してください",
+    "Could not leave the team {displayName}" : "チーム{displayName}から離脱できませんでした",
+    "Unable to join the team" : "チームに参加できません",
     "You are about to delete {circle}.\nAre you sure?" : "{circle}を削除しようとしています。\nよろしいですか？",
+    "Please confirm team deletion" : "チームの削除を確認してください",
+    "Unable to delete the team" : "チームを削除できません",
     "Link copied to the clipboard" : "クリップボードにリンクをコピーしました",
     "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
     "Not grouped" : "グループ化されていません",
     "Recently contacted" : "最近連絡した",
     "Organization chart" : "組織図",
+    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "チームは、自分で作成し、データを共有できるユーザーのグループです。Nextcloudインスタンスの他のアカウントやアカウントのグループだけでなく、アドレス帳の連絡先や、電子メールアドレスを入力するだけの外部のユーザーで構成することもできます。",
+    "Team" : "チーム",
     "User" : "ユーザー",
     "Group" : "グループ",
     "Email" : "メール",
@@ -190,12 +243,16 @@ OC.L10N.register(
     "Invites" : "招待",
     "Anyone can request membership" : "誰でもメンバーへの参加をリクエストできます",
     "Members need to accept invitation" : "メンバーは招待を承認する必要があります",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
+    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "メンバシップはモデレータによって確認/承認される必要があります (「誰でもメンバシップをリクエストできます」が必要) 。",
     "Members can also invite" : "メンバーによる招待も可能",
     "Visibility" : "公開レベル",
     "Visible to everyone" : "すべての人に公開",
-    "Users" : "ユーザー",
-    "Email addresses" : "メールアドレス",
+    "Team membership" : "チームのメンバー",
+    "Prevent teams from being a member of another team" : "チームが別のチームのメンバーになることを禁止する",
+    "users" : "ユーザー",
+    "groups" : "グループ",
+    "teams" : "チーム",
+    "email addresses" : "メールアドレス",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
     "Prefix" : "プレフィックス",
@@ -255,6 +312,9 @@ OC.L10N.register(
     "Time zone" : "タイムゾーン",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
+    "An error has occurred in team(s). Check the console for more details." : "チームでエラーが発生しました。詳細については、コンソールを確認してください。",
+    "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
+    "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。"
 },
 "nplurals=1; plural=0;");
