@@ -6,13 +6,14 @@ OC.L10N.register(
     "Contacts" : "კონტაქტები",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
     "General settings" : "მთავარი პარამეტრები",
-    "Send email" : "ელ-წერილის გაგზავნა",
-    "Download" : "ჩამოტვირთვა",
     "Rename" : "სახელის შეცვლა",
+    "Send email" : "ელ-წერილის გაგზავნა",
     "Delete" : "გაუქმება",
+    "Download" : "ჩამოტვირთვა",
     "Copy link" : "ბმულის კოპირება",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეუძლია შეცვლა",
+    "Add" : "დამატება",
     "First name" : "სახელი",
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "Moderator" : "მოდერატორი",
     "Admin" : "ადმინისტრატორი",
     "Owner" : "მფლობელი",
-    "Users" : "მომხმარებლები",
     "Detailed name" : "დეტალური სახელი",
     "Additional names" : "დამატებითი სახელები",
     "Prefix" : "პრეფიქსი",
