@@ -18,15 +18,16 @@ OC.L10N.register(
     "Create contacts" : "연락처 만들기",
     "Add contacts" : "연락처 추가",
     "Loading …" : "불러오는 중 …",
-    "Add member" : "회원 추가",
     "Contacts settings" : "연락처 설정",
     "General settings" : "일반 설정",
     "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
     "(refreshed once per week)" : "(주 1회 새로고침)",
     "Address books" : "주소록",
+    "Rename" : "이름 바꾸기",
     "Export" : "내보내기",
     "Send email" : "이메일 보내기",
     "Send email as BCC" : "BCC로 이메일 보내기",
+    "Delete" : "삭제",
     "Contact groups" : "연락처 그룹",
     "Create a new contact group" : "새 연락처 그룹 생성",
     "Contact group name" : "연락처 그룹 이름",
@@ -36,8 +37,6 @@ OC.L10N.register(
     "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
     "Download" : "다운로드",
     "Show" : "보이기",
-    "Rename" : "이름 바꾸기",
-    "Delete" : "삭제",
     "Copied" : "복사됨",
     "Cannot copy" : "복사할 수 없음",
     "Copy link" : "링크 복사",
@@ -61,6 +60,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "주소록을 찾을 수 없어서 가져올 수 없습니다.",
     "Choose a vCard file to import" : "불러올 vCard 파일을 고르기",
     "Add new address book" : "새 주소록 생성",
+    "Add" : "Add",
     "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "First name" : "이름",
     "Last name" : "성",
@@ -77,7 +77,6 @@ OC.L10N.register(
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
     "Request to join" : "등록 요청",
     "Description" : "설명",
-    "Add members" : "회원 추가",
     "Settings" : "Settings",
     "An error happened during description sync" : "설명 동기화 중 오류 발생",
     "An error happened during name sync" : "이름 동기화 중 오류 발생",
@@ -103,6 +102,8 @@ OC.L10N.register(
     "Name" : "이름",
     "Title" : "직위",
     "Company" : "회사",
+    "Go to talk conversation" : "Talk 대화로 이동",
+    "View profile" : "프로필 보기",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "연락처가 잘못되었으며 수정이 필요합니다. 내용을 점검하고 여기를 눌러 저장하십시오.",
     "Edit" : "편집",
     "Clone contact" : "연락처 복제",
@@ -110,8 +111,6 @@ OC.L10N.register(
     "Contact vCard as QR code" : "QR 코드로 된 vCard 연락처",
     "Pick an address book" : "주소록 선택",
     "Select address book" : "주소록 선택",
-    "Go to talk conversation" : "Talk 대화로 이동",
-    "View profile" : "프로필 보기",
     "Media shares with you" : "나와 공유된 미디어",
     "Talk conversations with you" : "나와의 Talk 대화",
     "Calendar events with you" : "나와의 달력 일정",
@@ -138,6 +137,7 @@ OC.L10N.register(
     "Add {type}" : "{type} 추가",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
     "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
+    "Add members" : "회원 추가",
     "Add to {circle}" : "{circle}에 추가",
     "Unable to get the recommendations list" : "추천 목록을 받아올 수 없음",
     "Unable to get the results" : "결과를 받아올 수 없음",
@@ -190,12 +190,9 @@ OC.L10N.register(
     "Invites" : "초대",
     "Anyone can request membership" : "누구나 가입을 요청할 수 있음",
     "Members need to accept invitation" : "회원이 초대를 수락해야 함",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "중재자가 회원 가입을 확인 및 수락해야 합니다. (요청 가능)",
     "Members can also invite" : "회원도 초대 가능",
     "Visibility" : "표시 여부",
     "Visible to everyone" : "모두에게 보이기",
-    "Users" : "사용자",
-    "Email addresses" : "이메일 주소",
     "Detailed name" : "자세한 이름",
     "Additional names" : "추가 이름",
     "Prefix" : "접두사",
