@@ -6,15 +6,15 @@ OC.L10N.register(
     "Contacts" : "Харилцагчид",
     "Copy to full name" : "Бүтэн нэр хуулах",
     "Loading …" : "Уншиж байна...",
-    "Add member" : "Гишүүн нэмэх",
-    "Download" : "Татаж авах",
     "Rename" : "Нэр солих",
     "Delete" : "Устгах",
+    "Download" : "Татаж авах",
     "Copied" : "Хуулагдсан",
     "Cannot copy" : "Хуулагдаагүй",
     "Copy link" : "Холбоос хуулах",
     "Share with users or groups" : "Бусдад түгээх",
     "can edit" : "засаж чадна",
+    "Add" : "нэмэх",
     "First name" : "Нэр",
     "Last name" : "Овог",
     "Display name" : "Харагдах нэр",
@@ -47,7 +47,6 @@ OC.L10N.register(
     "Moderator" : "Шалгагч",
     "Admin" : "Админ",
     "Owner" : "Эзэмшигч",
-    "Users" : "хэрэглэгч",
     "Detailed name" : "Дэлгэрэнгүй нэр",
     "Additional names" : "Нэмэлт нэрүүд",
     "Nickname" : "Товч нэр",
