@@ -6,15 +6,16 @@ OC.L10N.register(
     "Contacts" : "Contacte",
     "Loading contacts …" : "Se încarcă contactele ...",
     "Loading …" : "Se încarcă…",
-    "Send email" : "Trimite email-ul",
-    "Download" : "Descărcare",
     "Rename" : "Redenumește",
+    "Send email" : "Trimite email-ul",
     "Delete" : "Șterge",
+    "Download" : "Descărcare",
     "Copied" : "Copiat",
     "Copy link" : "Copiază linkul",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
     "can edit" : "poate edita",
+    "Add" : "Add",
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
@@ -47,7 +48,6 @@ OC.L10N.register(
     "Admin" : "Admin",
     "Owner" : "Proprietar",
     "Visibility" : "Vizibil",
-    "Users" : "Utilizatori",
     "Detailed name" : "Nume detaliat",
     "Additional names" : "Nume adiționale",
     "Prefix" : "Prefix",
