@@ -2,9 +2,10 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "ئالاقەداشلار",
-    "Download" : "چۈشۈر",
     "Rename" : "ئات ئۆزگەرت",
     "Delete" : "ئۆچۈر",
+    "Download" : "چۈشۈر",
+    "Add" : "قوش",
     "First name" : "ئاتى",
     "Password protection" : "Password protection",
     "Save" : "ساقلا",
@@ -21,7 +22,6 @@ OC.L10N.register(
     "Group" : "Group",
     "Email" : "تورخەت",
     "Owner" : "Owner",
-    "Users" : "ئىشلەتكۈچىلەر",
     "Nickname" : "تەخەللۇس",
     "Notes" : "ئىزاھاتلار",
     "Location" : "ئورنى",
