@@ -18,15 +18,16 @@ OC.L10N.register(
     "Create contacts" : "新建联系人",
     "Add contacts" : "添加联系人",
     "Loading …" : "正在加载…",
-    "Add member" : "添加成员",
     "Contacts settings" : "联系人设置",
     "General settings" : "一般设置",
     "Update avatars from social media" : "从社交媒体更新头像",
     "(refreshed once per week)" : "（每周刷新）",
     "Address books" : "地址簿",
+    "Rename" : "重命名",
     "Export" : "导出",
     "Send email" : "发送邮件",
     "Send email as BCC" : "以抄送模式发送邮件",
+    "Delete" : "删除",
     "Contact groups" : "联系人群组",
     "Create a new contact group" : "创建联系人群组",
     "Contact group name" : "联系人群组名称",
@@ -36,8 +37,6 @@ OC.L10N.register(
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下载",
     "Show" : "显示",
-    "Rename" : "重命名",
-    "Delete" : "删除",
     "Copied" : "已复制",
     "Cannot copy" : "无法复制",
     "Copy link" : "复制链接",
@@ -62,6 +61,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Add new address book" : "添加新通讯录",
+    "Add" : "Add",
     "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
     "First name" : "名",
     "Last name" : "姓",
@@ -78,9 +78,14 @@ OC.L10N.register(
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
+    "Team settings" : "团队设置",
     "Request to join" : "请求加入",
     "Description" : "描述",
-    "Add members" : "添加成员",
+    "Members" : "成员",
+    "Manage members" : "管理成员",
+    "Team members" : "团队成员",
+    "Team resources" : "团队资源",
+    "Team name" : "团队名称",
     "Settings" : "Settings",
     "An error happened during description sync" : "描述同步期间发生一个错误",
     "An error happened during name sync" : "名称同步期间发生了一个错误",
@@ -107,6 +112,8 @@ OC.L10N.register(
     "Name" : "名称",
     "Title" : "头衔",
     "Company" : "公司",
+    "Go to talk conversation" : "前往对话",
+    "View profile" : "查看个人资料",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人资料损坏但已被修复。请查看内容并点击这里以保存它。",
     "Edit" : "编辑",
     "Clone contact" : "克隆联系人",
@@ -114,8 +121,6 @@ OC.L10N.register(
     "Contact vCard as QR code" : "联系人名片作为二维码",
     "Pick an address book" : "选择一个地址簿",
     "Select address book" : "选择地址簿",
-    "Go to talk conversation" : "前往对话",
-    "View profile" : "查看个人资料",
     "Media shares with you" : "与您分享的媒体",
     "Talk conversations with you" : "与您展开的对话",
     "Calendar events with you" : "与您分享的日历事件",
@@ -141,8 +146,10 @@ OC.L10N.register(
     "No results" : "无结果",
     "Add to group" : "添加到群组",
     "Add {type}" : "添加  {type}",
+    "New team name" : "新团队名称",
     "Loading members list …" : "正在加载成员列表 ...",
     "You currently have no access to the member list" : "您目前无法访问成员列表",
+    "Add members" : "添加成员",
     "Add to {circle}" : "添加到 {circle}",
     "Unable to get the recommendations list" : "无法获取推荐列表",
     "Unable to get the results" : "无法获得结果",
@@ -180,12 +187,14 @@ OC.L10N.register(
     "Are you sure you want to import this contact file?" : "您确定您想要导入此联系人文件吗？",
     "Could not copy" : "无法复制",
     "You are about to leave {circle}.\nAre you sure?" : "您即将离开 {circle}\n确定吗？",
+    "Could not leave the team {displayName}" : "无法离开团队 {显示名称}",
     "You are about to delete {circle}.\nAre you sure?" : "您即将删除 {circle}\n确定吗？",
     "Link copied to the clipboard" : "链接已复制到剪贴板",
     "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
+    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "团队是一群人，你可以自己创建，也可以与他们共享数据。它们可以由Nextcloud实例的其它账户或帐户组组成，也可以由通讯簿中的联系人组成，甚至可以由外部人员组成，只需输入他们的电子邮件地址即可。",
     "User" : "用户",
     "Group" : "小组",
     "Email" : "电子邮件",
@@ -197,12 +206,10 @@ OC.L10N.register(
     "Invites" : "邀请",
     "Anyone can request membership" : "任何人均可请求成员资格",
     "Members need to accept invitation" : "成员需要接受邀请",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成员资格必须由一名主持人确认/接受（必须为开放圈子）",
     "Members can also invite" : "成员也可以邀请",
     "Visibility" : "可见性",
     "Visible to everyone" : "对所有人可见",
-    "Users" : "用户",
-    "Email addresses" : "电子邮件地址",
+    "Team membership" : "团队成员",
     "Detailed name" : "全名",
     "Additional names" : "其他名称",
     "Prefix" : "前缀",
@@ -262,6 +269,7 @@ OC.L10N.register(
     "Time zone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "Unable to create team {circleName}" : "无法创建团队 {圈子名称}",
     "Unable to delete contact" : "无法删除联系人"
 },
 "nplurals=1; plural=0;");
