@@ -21,7 +21,7 @@ OC.L10N.register(
     "Create contacts" : "建立聯絡人",
     "Add contacts" : "新增聯絡人",
     "Loading …" : "正在載入 …",
-    "Add member" : "添加成員",
+    "Manage team" : "管理團隊",
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
     "Contacts settings" : " 通訊錄設定",
@@ -29,14 +29,17 @@ OC.L10N.register(
     "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
+    "Rename" : "重新命名",
     "Export" : "導出",
     "Send email" : "傳送電郵",
     "Send email as BCC" : "以 BCC 方式發送電郵",
+    "Delete" : "刪除",
     "Contact groups" : "聯絡群組",
     "Create a new contact group" : "創建新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
     "Teams" : "團隊",
     "Create a new team" : "創建新團隊",
+    "Open the contacts app settings" : "開啟通訊錄應用程式設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "收合群組",
     "Show all teams" : "顯示所有團隊",
@@ -47,14 +50,15 @@ OC.L10N.register(
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下載",
     "Show" : "顯示",
-    "Rename" : "重新命名",
-    "Delete" : "刪除",
+    "Unshare from me" : "取消與我分享",
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
     "Copy link" : "複製連結",
     "Toggling of address book was not successful" : "通訊錄切換失敗",
     "This will delete the address book and every contacts within it" : "這將刪除通訊錄及其所有的聯絡人",
     "Delete {addressbook}?" : "刪除 {addressbook}？",
+    "This will unshare the address book and every contacts within it" : "這將會取消分享通訊錄與其中的每個聯絡人",
+    "Unshare {addressbook}?" : "取消分享 {addressbook}？",
     "Deletion of address book was not successful." : "刪除通訊錄失敗。",
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
     "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
@@ -73,11 +77,12 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
     "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
     "Add new address book" : "添加新通訊錄",
+    "Add" : "加入",
     "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "First name" : "名",
     "Last name" : "姓",
-    "Phonetic first name" : "語音名",
-    "Phonetic last name" : "語音姓",
+    "Phonetic first name" : "音頻名",
+    "Phonetic last name" : "音頻姓",
     "Display name" : "顯示名稱",
     "Last modified" : "上次修改",
     "Sort by {sorting}" : "按 {sorting} 排序",
@@ -96,7 +101,7 @@ OC.L10N.register(
     "Request to join" : "請求加入",
     "Description" : "描述",
     "Members" : "成員",
-    "Add members" : "添加成員",
+    "Manage members" : "管理成員",
     "Team members" : "團隊成員",
     "Team resources" : "團隊資源",
     "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
@@ -130,6 +135,8 @@ OC.L10N.register(
     "Name" : "姓名",
     "Title" : "職銜",
     "Company" : "公司名稱",
+    "Go to talk conversation" : "前往對話",
+    "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
     "Edit" : "編輯",
     "Clone contact" : "複製聯絡人",
@@ -137,8 +144,6 @@ OC.L10N.register(
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
     "Pick an address book" : "選取一個通訊錄",
     "Select address book" : "選擇通訊錄",
-    "Go to talk conversation" : "前往對話",
-    "View profile" : "檢視個人檔案",
     "Media shares with you" : "與您分享的媒體",
     "Talk conversations with you" : "與您的 Talk 對話",
     "Calendar events with you" : "與您分享的日曆活動",
@@ -173,6 +178,7 @@ OC.L10N.register(
     "Loading members list …" : "正在加載成員清單 …",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取會員清單",
+    "Add members" : "添加成員",
     "Show team details" : "顯示團隊詳細資訊",
     "Add to {circle}" : "添加到 {circle}",
     "Unable to get the recommendations list" : "無法獲取推薦列表",
@@ -237,14 +243,16 @@ OC.L10N.register(
     "Invites" : "邀請",
     "Anyone can request membership" : "任何人都可以申請加入",
     "Members need to accept invitation" : "會員需要接受邀請",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "會員資格必須由版主確認/接受（需要開放）",
+    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "會員資格必須由主持人確認/接受（要求「任何人都可以申請會員資格」）",
     "Members can also invite" : "會員也可以邀請",
     "Visibility" : "可見性",
     "Visible to everyone" : "所有人都看得到",
     "Team membership" : "團隊成員身分",
     "Prevent teams from being a member of another team" : "防止團隊成為另一個團隊的成員",
-    "Users" : "用戶",
-    "Email addresses" : "電郵地址",
+    "users" : "用戶",
+    "groups" : "群組",
+    "teams" : "團隊",
+    "email addresses" : "電郵地址",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
     "Prefix" : "前綴",
@@ -276,7 +284,7 @@ OC.L10N.register(
     "Fax home" : "傳真（家）",
     "Fax work" : "傳真（業務）",
     "Pager" : "傳呼機",
-    "Voice" : "語音",
+    "Voice" : "音頻",
     "Car" : "車子",
     "Work pager" : "傳呼機（業務）",
     "Manager" : "上司",
