@@ -21,7 +21,7 @@ OC.L10N.register(
     "Create contacts" : "建立聯絡人",
     "Add contacts" : "新增聯絡人",
     "Loading …" : "正在載入……",
-    "Add member" : "新增成員",
+    "Manage team" : "管理團隊",
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
     "Contacts settings" : "聯絡人設定",
@@ -29,14 +29,17 @@ OC.L10N.register(
     "Update avatars from social media" : "從社群媒體更新大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
+    "Rename" : "重新命名",
     "Export" : "匯出",
     "Send email" : "傳送電子郵件",
     "Send email as BCC" : "以密件副本傳送電子郵件",
+    "Delete" : "刪除",
     "Contact groups" : "聯絡人群組",
     "Create a new contact group" : "建立新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
     "Teams" : "團隊",
     "Create a new team" : "建立新團隊",
+    "Open the contacts app settings" : "開啟通訊錄應用程式設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "折疊群組",
     "Show all teams" : "顯示所有團隊",
@@ -47,14 +50,15 @@ OC.L10N.register(
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下載",
     "Show" : "顯示",
-    "Rename" : "重新命名",
-    "Delete" : "刪除",
+    "Unshare from me" : "取消與我分享",
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
     "Copy link" : "複製連結",
     "Toggling of address book was not successful" : "通訊錄切換失敗",
     "This will delete the address book and every contacts within it" : "這將會刪除通訊與其中的每個聯絡人",
     "Delete {addressbook}?" : "刪除 {addressbook}？",
+    "This will unshare the address book and every contacts within it" : "這將會取消分享通訊錄與其中的每個聯絡人",
+    "Unshare {addressbook}?" : "取消分享 {addressbook}？",
     "Deletion of address book was not successful." : "刪除通訊錄失敗。",
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
     "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
@@ -73,6 +77,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "已停用匯入，因為沒有可用的通訊錄",
     "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
     "Add new address book" : "加入新的通訊錄",
+    "Add" : "Add",
     "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "First name" : "名",
     "Last name" : "姓",
@@ -96,7 +101,7 @@ OC.L10N.register(
     "Request to join" : "要求加入",
     "Description" : "描述",
     "Members" : "成員",
-    "Add members" : "新增成員",
+    "Manage members" : "管理成員",
     "Team members" : "團隊成員",
     "Team resources" : "團隊資源",
     "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
@@ -130,6 +135,8 @@ OC.L10N.register(
     "Name" : "名稱",
     "Title" : "標題",
     "Company" : "公司",
+    "Go to talk conversation" : "前往對話",
+    "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
     "Edit" : "編輯",
     "Clone contact" : "再製連絡人",
@@ -137,8 +144,6 @@ OC.L10N.register(
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
     "Pick an address book" : "選取一個通訊錄",
     "Select address book" : "選擇通訊錄",
-    "Go to talk conversation" : "前往對話",
-    "View profile" : "檢視個人檔案",
     "Media shares with you" : "與您分享的媒體",
     "Talk conversations with you" : "與您的 Talk 對話",
     "Calendar events with you" : "有您的日曆事件",
@@ -173,6 +178,7 @@ OC.L10N.register(
     "Loading members list …" : "正在載入成員清單……",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取成員清單",
+    "Add members" : "新增成員",
     "Show team details" : "顯示團隊詳細資訊",
     "Add to {circle}" : "新增至 {circle}",
     "Unable to get the recommendations list" : "無法取得建議清單",
@@ -237,14 +243,16 @@ OC.L10N.register(
     "Invites" : "邀請",
     "Anyone can request membership" : "任何人都可以請求成員資格",
     "Members need to accept invitation" : "成員必須接受邀請",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成員資格必須由主持人（必須為開放小圈圈）確認／接受",
+    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成員資格必須由主持人確認／接受（必須為「任何人都可以請求成員資格）",
     "Members can also invite" : "成員也可以邀請",
     "Visibility" : "能見度",
     "Visible to everyone" : "對所有人可見",
     "Team membership" : "團隊成員資格",
     "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
-    "Users" : "使用者",
-    "Email addresses" : "電子郵件地址",
+    "users" : "使用者",
+    "groups" : "群組",
+    "teams" : "團隊",
+    "email addresses" : "電子郵件地址",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
     "Prefix" : "前綴",
